@@ -8,9 +8,9 @@ pyside_library_soversion = str(5.15)
 version = "5.15.16"
 version_info = (5, 15, 16, "", "")
 
-__build_date__ = '2025-07-27T20:28:10+00:00'
-__build_commit_date__ = '2025-07-24T19:10:19+00:00'
-__build_commit_hash__ = '50c5d7b0badea6b84beb5e5e7210c27b7c36f6a4'
+__build_date__ = '2024-12-11T12:28:21+00:00'
+
+
 
 
 
